@@ -3,6 +3,9 @@ from ._tools import (
     plot_confusion_matrix2,
     plot_roc,
     plot_multi_class_roc,
+    plot_corr,
+    plot_lines,
+    plot_image_boxes
 )
 
 __all__ = [
@@ -10,4 +13,7 @@ __all__ = [
     "plot_confusion_matrix2",
     "plot_roc",
     "plot_multi_class_roc",
+    "plot_corr",
+    "plot_lines",
+    "plot_image_boxes"
 ]
